<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>OTR Encryption</source>
        <translation>Cryptage OTR</translation>
    </message>
    <message>
        <source>Create private key started</source>
        <translation>Création de la clé privé commencé</translation>
    </message>
    <message>
        <source>Create private key finished</source>
        <translation>La création de la clef privée s&apos;est terminée</translation>
    </message>
</context>
<context>
    <name>OtrAccountConfigurationWidget</name>
    <message>
        <source>Enable private messaging</source>
        <translation>Activer la conversation privé</translation>
    </message>
    <message>
        <source>Automatically initiate private messaging</source>
        <translation>Automatiquement initier la conversation privé</translation>
    </message>
    <message>
        <source>Require private messaging</source>
        <translation>Exiger une conversation privé</translation>
    </message>
    <message>
        <source>OTR Encryption</source>
        <translation>Cryptage OTR</translation>
    </message>
</context>
<context>
    <name>OtrBuddyConfigurationWidget</name>
    <message>
        <source>Use account&apos;s policy</source>
        <translation>Utiliser les paramètres du compte</translation>
    </message>
    <message>
        <source>Enable private messaging</source>
        <translation>Activer la conversation privé</translation>
    </message>
    <message>
        <source>Automatically initiate private messaging</source>
        <translation>Automatiquement initier la conversation privé</translation>
    </message>
    <message>
        <source>Require private messaging</source>
        <translation>Exiger conversation privé</translation>
    </message>
    <message>
        <source>OTR Encryption</source>
        <translation>Cryptage OTR</translation>
    </message>
</context>
<context>
    <name>OtrChatTopBarWidget</name>
    <message>
        <source>Start Private Conversation</source>
        <translation>Démarrer Conversion Privé</translation>
    </message>
    <message>
        <source>End Private Conversation</source>
        <translation>Termine Conversation Privé</translation>
    </message>
    <message>
        <source>Verify Peer Identity</source>
        <translation>Vérifier l&apos;Identité du Destinataire</translation>
    </message>
    <message>
        <source>Refresh Private Conversation</source>
        <translation>Rafraichir Conversation Privé</translation>
    </message>
    <message>
        <source>Unverified</source>
        <translation>Non vérifié</translation>
    </message>
    <message>
        <source>Private</source>
        <translation>Privée</translation>
    </message>
    <message>
        <source>Not Private</source>
        <translation>Non Privé</translation>
    </message>
</context>
<context>
    <name>OtrErrorMessageService</name>
    <message>
        <source>Error occurred during message encryption</source>
        <translation>Une erreur s&apos;est produite durant la cryptage</translation>
    </message>
    <message>
        <source>You sent encrypted data to %1, who wasn&apos;t expecting it</source>
        <translation>Vous avez envoyé un message crypté à %1 qui n&apos;était pas prédisposé pour</translation>
    </message>
    <message>
        <source>You transmitted an unreadable encrypted message</source>
        <translation>Vous avez transmis un message crypté non lisible</translation>
    </message>
    <message>
        <source>You transmitted a malformed data message</source>
        <translation>Vous avez transmis un message composé de données mal formés</translation>
    </message>
</context>
<context>
    <name>OtrMessageEventService</name>
    <message>
        <source>Unencrypted messages to %1 are not allowed. Attmpting to start a private conversation...</source>
        <translation>Les messages non cryptés à %1 ne sont pas autorisé. Tentative de d&apos;initialisation d&apos;une conversation privé...</translation>
    </message>
    <message>
        <source>Encryption error. Message was not sent.</source>
        <translation>Erreur de cryptage. Le message a été renvoyé.</translation>
    </message>
    <message>
        <source>Message was not sent. Private conversation was closed by %1. Either restart or close your private conversation.</source>
        <translation>Le message n&apos;a pas été envoyé. La conversation privé a été fermé par %1. Redémarrez ou fermez la conversation privé.</translation>
    </message>
    <message>
        <source>Error during setting up private conversation with %1: %2</source>
        <translation>Erreur durant l&apos;établissement de la conversation privé avec %1 : %2</translation>
    </message>
    <message>
        <source>We are receiving our own OTR messages from %1. Either restart or close your private conversation.</source>
        <translation>Nous sommes en train de recevoir nos propres messages OTR de %1. Redémarrez ou fermez la conversation privé.</translation>
    </message>
    <message>
        <source>Last message was resent: %1</source>
        <translation>Le dernier message a été renvoyé: %1</translation>
    </message>
    <message>
        <source>Message from %1 was unreadable, as you are not currently communicating privately.</source>
        <translation>Le message de %1 est illisible car vous ne communiquez pas en privé.</translation>
    </message>
    <message>
        <source>Message from %1 was unreadable.</source>
        <translation>Le message de %1 n&apos;a pu être lu.</translation>
    </message>
    <message>
        <source>Message from %1 was malformed.</source>
        <translation>Le message de %1 a été mal formé.</translation>
    </message>
    <message>
        <source>Encryption error: %1</source>
        <translation>Erreur de cryptage: %1</translation>
    </message>
    <message>
        <source>Message from %1 was unencrypted.</source>
        <translation>Le message de %1 était non crypté.</translation>
    </message>
    <message>
        <source>Message from %1 was unrecognized.</source>
        <translation>Le message de %1 n&apos;a pas été reconnu.</translation>
    </message>
    <message>
        <source>%1 has sent a message intended for different session. If you are logged in multiple times another session may have received the message.</source>
        <translation>%1 a envoyé un message destiné à une autre session. Si vous êtes authentifié à plusieurs endroits une autre session a probablement reçu le message.</translation>
    </message>
    <message>
        <source>Malformed message received</source>
        <translation>Message mal formé reçu</translation>
    </message>
</context>
<context>
    <name>OtrMessageService</name>
    <message>
        <source>[resent]</source>
        <translation>[renvoyé]</translation>
    </message>
</context>
<context>
    <name>OtrNotifier</name>
    <message>
        <source>OTR Encryption</source>
        <translation>Cryptage OTR</translation>
    </message>
    <message>
        <source>%1: trying to start private conversation</source>
        <translation>%1: essaye d&apos;initier une conversation privé</translation>
    </message>
    <message>
        <source>%1: trying to refresh private conversation</source>
        <translation>%1: essaye de rafraichir la conversation privé</translation>
    </message>
    <message>
        <source>%1: peer ended private conversation; you should do the same</source>
        <translation>%1: le destinataire a terminé la conversation privé; vous devriez faire de même</translation>
    </message>
    <message>
        <source>%1: private conversation started</source>
        <translation>%1: conversation privé démarré</translation>
    </message>
    <message>
        <source>%1: private conversation stopped</source>
        <translation>%1: conversation privé arrêté</translation>
    </message>
    <message>
        <source>%1: conversation is still private</source>
        <translation>%1: la conversation est toujours privé</translation>
    </message>
    <message>
        <source>%1: creating private key, it can took a few minutes</source>
        <translation>%1: création de la clé privé en cours, ce traitement peut durer quelques minutes</translation>
    </message>
    <message>
        <source>%1: private key created, you can start a private conversation now</source>
        <translation>%1: clé privé créé, vous pouvez désormais démarrer une conversation privé</translation>
    </message>
    <message>
        <source>%1: private key creation failed</source>
        <translation>%1: la création de la clé privé à échoué</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationFingerprintExchangePage</name>
    <message>
        <source>Fingerprint Exchange</source>
        <translation>Échange d&apos;empreinte digital</translation>
    </message>
    <message>
        <source>Your Key Fingerprint (%1: %2):</source>
        <translation>Votre Clé d&apos;Empreinte digitale (%1: %2)</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; Key Fingerprint (%2: %3):</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; Clé Empreinte Digitale (%2: %3):</translation>
    </message>
    <message>
        <source>I&apos;m not sure if above Key Fingerprint belongs to %1</source>
        <translation>Je ne suis pas sûr que la clé ci-dessus appartient à %1</translation>
    </message>
    <message>
        <source>I confirm that above Key Fingerprint belongs to %1</source>
        <translation>Je confirme que la clé ci-dessus appartient à %1</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationProgressPage</name>
    <message>
        <source>Verification Progress</source>
        <translation>Vérification en cours</translation>
    </message>
    <message>
        <source>Verification in progres...</source>
        <translation>Vérification en cours...</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationQuestionAndAnswerPage</name>
    <message>
        <source>Ask Question</source>
        <translation>Demander Question</translation>
    </message>
    <message>
        <source>Question and Answer</source>
        <translation>Question et Réponse</translation>
    </message>
    <message>
        <source>Question that only %1 can answer:</source>
        <translation>Question que seul %1 peut répondre:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Réponse:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationRespondQuestionAndAnswerPage</name>
    <message>
        <source>Answer Question</source>
        <translation>Réponse Question</translation>
    </message>
    <message>
        <source>Respond to Question and Answer</source>
        <translation>Répondre à Question et réponse</translation>
    </message>
    <message>
        <source>%1 wants to verify your identity using Question and Answer method.</source>
        <translation>%1 veut vérifier votre identité avec la méthode Question Réponse.</translation>
    </message>
    <message>
        <source>%1 question:</source>
        <translation>%1 question:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Réponse :</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationRespondSharedSecretPage</name>
    <message>
        <source>Send Shared Secret</source>
        <translation>Envoyer Secret Partagé</translation>
    </message>
    <message>
        <source>Respond to Shared Secret</source>
        <translation>Répondre au Secret partagé</translation>
    </message>
    <message>
        <source>%1 wants to verify your identity using Shared Secret method.</source>
        <translation>%1 veut vérifier votre identité avec la méthode Secret Partagé.</translation>
    </message>
    <message>
        <source>Shared Secret that is known only for you and %1:</source>
        <translation>Secret Partagé qui est seulement connu de vous et %1:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationResultPage</name>
    <message>
        <source>Verification Result</source>
        <translation>Résultat de Vérification</translation>
    </message>
    <message>
        <source>Verificationof %1 failed. You are probably talking to an imposter. Either close conversation or try other verification method.</source>
        <translation>Vérification de %1 échoué. Vous être probablement en train de parler à un imposteur. Fermer la conversation ou essayer une autre méthode de vérification.</translation>
    </message>
    <message>
        <source>%1 has verified you. You should do the same.</source>
        <translation>%1 a vérifié votre identité. Vous devriez faire de même.</translation>
    </message>
    <message>
        <source>Verification of %1 succeeded.</source>
        <translation>Vérification de %1 effectué avec succès.</translation>
    </message>
    <message>
        <source>Unknown.</source>
        <translation>Inconnu.</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationSelectMethodPage</name>
    <message>
        <source>Select Verification Method</source>
        <translation>Sélectionner Méthode Vérification</translation>
    </message>
    <message>
        <source>Question and Answer</source>
        <translation>Question et Réponse</translation>
    </message>
    <message>
        <source>Shared Secred</source>
        <translation>Secret Partagé</translation>
    </message>
    <message>
        <source>Fingerprint Exchange</source>
        <translation>Échange d&apos;empreinte digital</translation>
    </message>
    <message>
        <source>Ask peer a question that only you and he/she know the answer for. If your peer answer it properly, he/she will be marked as verified.</source>
        <translation>Demander au destinataire une question dont seul vous et lui connaissent la réponse. Si votre question est correctement répondu, le destinataire sera marqué comme vérifié.</translation>
    </message>
    <message>
        <source>Exchange a secret message with peer. This message should be agreed to on another secure channel (face-to-face conversation or a phone).</source>
        <translation>Échanger un message secret avec le destinataire. Ce message devrait être échangé depuis une autre source de communication sécurisé ( conversation directe ou au téléphone ).</translation>
    </message>
    <message>
        <source>Check your peer&apos;s fingerprint manually. Fingreprint information shoud be exchanged on another secure channel (face-to-face conversation or a phone).</source>
        <translation>Vérifier l&apos;empreinte digitale du destinataire. L&apos;empreinte digitale devrait être échanger via une autre source de communication sécurisé( conversation directe ou via téléphone).</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationSharedSecretPage</name>
    <message>
        <source>Ask for Shared Secret</source>
        <translation>Demander à Partager un Secret</translation>
    </message>
    <message>
        <source>Shared Secret</source>
        <translation>Secret Partagé</translation>
    </message>
    <message>
        <source>Shared Secret that is known only for you and %1:</source>
        <translation>Partager un Secret que seul vous et %1 connaissent:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationWindow</name>
    <message>
        <source>Verify Identity of %1</source>
        <translation>Vérifier l&apos;Identité de %1</translation>
    </message>
</context>
<context>
    <name>OtrPluginObject</name>
    <message>
        <source>OTR encryption library could not be initialized</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>